"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const src_1 = require("../../src");
function xmlCheck(req, res, next) {
    res.write("finish");
    res.end();
}
exports.xmlCheck = xmlCheck;
let cookieRsaAes = src_1.CacheMoudle.createCache('RsaAesServer', 30 * 1000);
function getRasAesServer(code) {
    if (!code)
        return undefined;
    if (!cookieRsaAes.has(code))
        cookieRsaAes.set(code, new src_1.RsaAesServer(1024, 'pkcs1', true));
    return cookieRsaAes.get(code);
}
function stepOne(req, res, next) {
    if (req.body.rsaid)
        cookieRsaAes.del(req.body.rsaid);
    res.setHeader('Set-Cookie', 'rsaaescode=' + req.body.rsaid);
    let server = getRasAesServer(req.body.rsaid);
    if (server) {
        res.write(server.stepOne(req.body.format || 'public'));
    }
    res.end();
}
exports.stepOne = stepOne;
function stepTwo(req, res, next) {
    let server = getRasAesServer(req.body.rsaid);
    if (server) {
        let result = server.stepTwo(Buffer.from(req.body.key, 'base64'), req.body.format, req.body.encryptionScheme);
        res.write(result.toString('base64'));
    }
    res.end();
}
exports.stepTwo = stepTwo;
function stepMessage(req, res, next) {
    let server = getRasAesServer(req.body.rsaid);
    if (server) {
        res.write(server.decode(req.body.encryptedData, req.body.iv));
    }
    res.end();
}
exports.stepMessage = stepMessage;
// export function test(req: Request, res: Response, next: NextFunction) {
//     let server = getRasAesServer(req.body.rsaid);
//     if (server) {
//         let out: Buffer;
//         if (req.body.type == 'decrypt') {
//             out = server.testDecrypt(req.body.mod || 'server', Buffer.from(req.body.data, 'base64'));
//         }
//         else if (req.body.type == 'encrypt') {
//             out = server.testEncrypt(req.body.mod || 'server', Buffer.from(req.body.data));
//         }
//         else
//             return next();
//         if (out) res.write(out.toString('base64'));
//     }
//     res.end();
// }
function testAes(req, res, next) {
    let out;
    let s = getRasAesServer(req.body.rsaid) || new src_1.RsaAesServer();
    if (req.body.aes)
        s.loadAes(req.body.aes);
    switch (req.body.type) {
        case 'decode':
            out = s.decode(req.body.encryptedData, req.body.iv);
            break;
        case 'encode':
            out = s.encode(req.body.data);
            break;
    }
    if (out)
        res.write(JSON.stringify(out));
    res.end();
}
exports.testAes = testAes;
function hello(req, res, next) {
    res.write('hello');
    res.end();
}
exports.hello = hello;
